==> rechn_mgm_web-0.1.0.gem: lib/rechn_mgm_web/document_basic_helper.rb <==
module RechnMgmWeb::DocumentBasicHelper
    def count_all_documents(is_appointed)
        if is_appointed
            all_documents(is_appointed).nil? ? 0 : all_documents(is_appointed).count
        else
            all_documents(is_appointed).nil? ? 0 : all_documents(is_appointed).count
        end
    end

    def all_documents(is_appointed)
        if current_user.present?
            Nukleus::Document.all_by_user_id(current_user.id, is_appointed)
        else
            session[:session_id].present? ? Nukleus::Document.all_by_session_id(session[:session_id], is_appointed) : nil
        end
    end

    def price_of_unpaid_documents
        price = 0.0
        all_documents(false).each { |doc| price += doc.price.to_f }
        price
    end

    def count_missing_documents
        if current_user.present?
            Nukleus::Document.where(user_id: current_user.id, document_version: 0).count - Nukleus::Document.where(user_id: current_user.id, document_version: 1).count
        else
            Nukleus::Document.where(session_id: session[:session_id], document_version: 0).count - Nukleus::Document.where(session_id: session[:session_id], document_version: 1).count
        end
    end

    def count_broken_documents
        if current_user.present?
            Nukleus::Document.where(user_id: current_user.id, :or => [ { :has_error => true }, { :meta_data => { :validation_state => { :pdf_state => { :is_broken => true } } } } ]).count
        else
            Nukleus::Document.where(session_id: session[:session_id], :or => [ { :has_error => true }, { :meta_data => { :validation_state => { :pdf_state => { :is_broken => true } } } } ]).count
        end
    end

    def count_unclean_documents
        if current_user.present?
            Nukleus::Document.where(user_id: current_user.id, :or => [ { :meta_data => { :validation_state => { :pdf_state => { :has_address_data => "0" } } } }, { :meta_data => { :validation_state => { :pdf_state => { :has_doc_errors => "1" } } } } ]).count
        else
            Nukleus::Document.where(session_id: session[:session_id], :or => [ { :meta_data => { :validation_state => { :pdf_state => { :has_address_data => "0" } } } }, { :meta_data => { :validation_state => { :pdf_state => { :has_doc_errors => "1" } } } } ]).count
        end
    end
end

==> rechn_mgm_web-0.1.39.gem: lib/rechn_mgm_web/document_basic_helper.rb <==
module RechnMgmWeb::DocumentBasicHelper
    def count_all_documents(is_appointed)
        if is_appointed
            all_documents(is_appointed).nil? ? 0 : all_documents(is_appointed).count
        else
            all_documents(is_appointed).nil? ? 0 : all_documents(is_appointed).count
        end
    end

    def all_documents(is_appointed)
        if current_user.present?
            Nukleus::Document.all_by_user(current_user.id, is_appointed)
        else
            session[:session_id].present? ? Nukleus::Document.all_by_session_id(session[:session_id], is_appointed) : nil
        end
    end

    def price_of_unpaid_documents
        price = 0.0
        all_documents(false).each { |doc| price += doc.price.to_f }
        price
    end

    def count_missing_documents
        if current_user.present?
            Nukleus::Document.where(user_id: current_user.id, document_version: 0).count - Nukleus::Document.where(user_id: current_user.id, document_version: 1).count
        else
            Nukleus::Document.where(session_id: session[:session_id], document_version: 0).count - Nukleus::Document.where(session_id: session[:session_id], document_version: 1).count
        end
    end

    def count_broken_documents
        if current_user.present?
            Nukleus::Document.where(user_id: current_user.id, :or => [ { :has_error => true }, { :meta_data => { :validation_state => { :pdf_state => { :is_broken => true } } } } ]).count
        else
            Nukleus::Document.where(session_id: session[:session_id], :or => [ { :has_error => true }, { :meta_data => { :validation_state => { :pdf_state => { :is_broken => true } } } } ]).count
        end
    end

    def count_unclean_documents
        if current_user.present?
            Nukleus::Document.where(user_id: current_user.id, :or => [ { :meta_data => { :validation_state => { :pdf_state => { :has_address_data => "0" } } } }, { :meta_data => { :validation_state => { :pdf_state => { :has_doc_errors => "1" } } } } ]).count
        else
            Nukleus::Document.where(session_id: session[:session_id], :or => [ { :meta_data => { :validation_state => { :pdf_state => { :has_address_data => "0" } } } }, { :meta_data => { :validation_state => { :pdf_state => { :has_doc_errors => "1" } } } } ]).count
        end
    end
end
